// ChunkFile.cs
//
// PRESTO Starter Kit for Microsoft .NET 3.0
// 2007 Microsoft France
// Published under the CECILL-B Free Software license agreement.
// (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
// 
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// WHETHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE. 
// THE ENTIRE RISK OF USE OR RESULTS IN CONNECTION WITH THE USE OF THIS CODE 
// AND INFORMATION REMAINS WITH THE USER. 
//

using System;
using System.Collections.Generic;
using System.Text;
using System.IO;

namespace Microsoft.Presto.StarterKit.NonNormative
{            
    public class ChunkingMessage
    {
        public static DirectoryInfo DownloadDir = new DirectoryInfo(Constants.Payloads.incomingFolder);

        public ChunkingMessage(int ChunkNumber, string filename)
        {
            if (!DownloadDir.Exists) DownloadDir.Create();
            this.fileInfo = new FileInfo(DownloadDir.FullName + "\\" + filename);
            if (fileInfo.Exists) fileInfo.Delete();
            
            this.chunkNumber = ChunkNumber;
            this.chunksReceived = new bool[ChunkNumber];
            for (int i = 0; i < chunkNumber; i++) chunksReceived[i] = false;
        }

        private int chunkNumber;
        public int ChunkNumber
        {
            get { return chunkNumber; }
        }

        private FileInfo fileInfo;
        public FileInfo FileInfo
        {
            get { return fileInfo; }
        }

        private bool[] chunksReceived;
        public bool[] ChunksReceived
        {
            get { return chunksReceived; }
        }

        public void WriteChunk(Chunk chunk)
        {
            if (! ((chunk != null) && (chunk.content != null)))
                return; 

            lock (this)
            {
                FileStream fstream = null;
                try
                {
                    fstream = File.Open(this.fileInfo.FullName, FileMode.OpenOrCreate, FileAccess.Write);
                    fstream.Position = chunk.startPosition;
                    fstream.Write(chunk.content, 0, chunk.length);
                    ChunksReceived[chunk.id] = true;
                }
                finally
                {
                    if (fstream != null) fstream.Close();
                }
            }
        }
    }
}
